
# Slot: contraindicated for


Holds between a drug and a disease or phenotype, such that a person with that disease should not be treated with the drug.

URI: [biolink:contraindicated_for](https://w3id.org/biolink/vocab/contraindicated_for)


## Domain and Range

[Drug](Drug.md) &#8594;  <sub>0..\*</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | DrugCentral:0000001 |
|  | | RTXKG1:contraindicated_for |

